Class: Sigstore::Common::V1::HashAlgorithm

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Enum
Defined in:
lib/sigstore/common/v1/sigstore_common_pb.rb

Overview

Only a subset of the secure hash standard algorithms are supported. See <nvlpubs.nist.gov/nistpubs/FIPS/NIST.FIPS.180-4.pdf> for more details. UNSPECIFIED SHOULD not be used, primary reason for inclusion is to force any proto JSON serialization to emit the used hash algorithm, as default option is to omit the default value of an enum (which is the first value, represented by ‘0’.

Constant Summary collapse

HASH_ALGORITHM_UNSPECIFIED =
new("HASH_ALGORITHM_UNSPECIFIED", 0).freeze
SHA2_256 =
new("SHA2_256", 1).freeze
SHA2_384 =
new("SHA2_384", 2).freeze
SHA2_512 =
new("SHA2_512", 3).freeze
SHA3_256 =

Used for LMS

new("SHA3_256", 4).freeze
SHA3_384 =

Used for LMS

new("SHA3_384", 5).freeze