Class: Sigstore::Common::V1::TimeRange

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Message
Defined in:
lib/sigstore/common/v1/sigstore_common_pb.rb

Overview

The time range is closed and includes both the start and end times, (i.e., [start, end]). End is optional to be able to capture a period that has started but has no known end.