Class: Sigstore::Common::V1::X509CertificateChain

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Message
Defined in:
lib/sigstore/common/v1/sigstore_common_pb.rb

Overview

A collection of X.509 certificates.

This “chain” can be used in multiple contexts, such as providing a root CA certificate within a TUF root of trust or multiple untrusted certificates for the purpose of chain building.