Class: Sigstore::Rekor::V1::InclusionProof

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Message
Defined in:
lib/sigstore/rekor/v1/sigstore_rekor_pb.rb

Overview

InclusionProof is the proof returned from the transparency log. Can be used for offline or online verification against the log.