Class: Sigstore::TrustRoot::V1::ServiceConfiguration

Inherits:
Object
  • Object
show all
Extended by:
Protobug::Message
Defined in:
lib/sigstore/trustroot/v1/sigstore_trustroot_pb.rb

Overview

ServiceConfiguration specifies how a client should select a set of Services to connect to, along with a count when a specific number of Services is requested.