Class: Sigstore::TrustRoot::V1::TrustedRoot
- Inherits:
-
Object
- Object
- Sigstore::TrustRoot::V1::TrustedRoot
- Extended by:
- Protobug::Message
- Defined in:
- lib/sigstore/trustroot/v1/sigstore_trustroot_pb.rb
Overview
TrustedRoot describes the client’s complete set of trusted entities. How the TrustedRoot is populated is not specified, but can be a combination of many sources such as TUF repositories, files on disk etc.
The TrustedRoot is not meant to be used for any artifact verification, only to capture the complete/global set of trusted verification materials. When verifying an artifact, based on the artifact and policies, a selection of keys/authorities are expected to be extracted and provided to the verification function. This way the set of keys/authorities can be kept to a minimal set by the policy to gain better control over what signatures that are allowed.
The embedded transparency logs, CT logs, CAs and TSAs MUST include any previously used instance – otherwise signatures made in the past cannot be verified.
All the listed instances SHOULD be sorted by the ‘valid_for.start’ in ascending order, that is, the oldest instance first. Clients MUST accept instances that overlaps in time, if not clients may experience problems during rotations of verification materials.
To be able to manage planned rotations of either transparency logs or certificate authorities, clienst MUST accept lists of instances where the last instance have a ‘valid_for’ that belongs to the future. This should not be a problem as clients SHOULD first seek the trust root for a suitable instance before creating a per artifact trust root (that is, a sub-set of the complete trust root) that is used for verification.