Class: Sigstore::TrustRoot::V1::Service
- Inherits:
-
Object
- Object
- Sigstore::TrustRoot::V1::Service
- Extended by:
- Protobug::Message
- Defined in:
- lib/sigstore/trustroot/v1/sigstore_trustroot_pb.rb
Overview
Service represents an instance of a service that is a part of Sigstore infrastructure. When selecting one or multiple services from a list of services, clients MUST:
-
Use the API version hint to determine the service with the highest API version that the client is compatible with.
-
Only select services within the specified validity period and that have the newest validity start date.
When selecting multiple services, clients MUST:
-
Use the ServiceConfiguration to determine how many services MUST be selected. Clients MUST return an error if there are not enough services that meet the selection criteria.
-
Group services by ‘operator` and select at most one service from an operator. During verification, clients MUST treat valid verification metadata from the operator as valid only once towards a threshold.
-
Select services from only the highest supported API version.