Class: Sigstore::TrustRoot::V1::ServiceSelector
- Inherits:
-
Object
- Object
- Sigstore::TrustRoot::V1::ServiceSelector
- Extended by:
- Protobug::Enum
- Defined in:
- lib/sigstore/trustroot/v1/sigstore_trustroot_pb.rb
Overview
ServiceSelector specifies how a client SHOULD select a set of Services to connect to. A client SHOULD throw an error if the value is SERVICE_SELECTOR_UNDEFINED.
Constant Summary collapse
- SERVICE_SELECTOR_UNDEFINED =
new("SERVICE_SELECTOR_UNDEFINED", 0).freeze
- ALL =
Clients SHOULD select all Services based on supported API version and validity window.
new("ALL", 1).freeze
- ANY =
Clients SHOULD select one Service based on supported API version and validity window. It is up to the client implementation to decide how to select the Service, e.g. random or round-robin.
new("ANY", 2).freeze
- EXACT =
Clients SHOULD select a specific number of Services based on supported API version and validity window, using the provided ‘count`. It is up to the client implementation to decide how to select the Service, e.g. random or round-robin.
new("EXACT", 3).freeze