Class: Sigstore::Verification::V1::Input
- Inherits:
-
Object
- Object
- Sigstore::Verification::V1::Input
- Extended by:
- Protobug::Message
- Defined in:
- lib/sigstore/verification/v1/sigstore_verification_pb.rb
Overview
Input captures all that is needed to call the bundle verification method, to verify a single artifact referenced by the bundle.